/*
 * Logswan 2.1.10
 * Copyright (c) 2015-2021, Frederic Cambus
 * https://www.logswan.org
 *
 * Created:      2015-05-31
 * Last Updated: 2021-02-15
 *
 * Logswan is released under the BSD 2-Clause license.
 * See LICENSE file for details.
 */

#ifndef CONTINENTS_H
#define CONTINENTS_H

extern char *continents_id[];
extern char *continents_names[];

#endif /* CONTINENTS */
